Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: chromeos/dbus/dbus_thread_manager.h

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/chromeos.gyp ('k') | chromeos/dbus/dbus_thread_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/dbus_thread_manager.h
diff --git a/chromeos/dbus/dbus_thread_manager.h b/chromeos/dbus/dbus_thread_manager.h
index f9d6f058a84187e59bea8f5ae49b55a3cd204155..90bfe8ae63b99e256c3088531ac3e4c850f1bc91 100644
--- a/chromeos/dbus/dbus_thread_manager.h
+++ b/chromeos/dbus/dbus_thread_manager.h
@@ -33,12 +33,12 @@ class CashewClient;
class CrosDisksClient;
class CryptohomeClient;
class DebugDaemonClient;
-class FlimflamDeviceClient;
-class FlimflamIPConfigClient;
-class FlimflamManagerClient;
-class FlimflamNetworkClient;
-class FlimflamProfileClient;
-class FlimflamServiceClient;
+class ShillDeviceClient;
+class ShillIPConfigClient;
+class ShillManagerClient;
+class ShillNetworkClient;
+class ShillProfileClient;
+class ShillServiceClient;
class GsmSMSClient;
class IBusClient;
class IBusEngineFactoryService;
@@ -156,35 +156,35 @@ class CHROMEOS_EXPORT DBusThreadManager {
// down.
virtual DebugDaemonClient* GetDebugDaemonClient() = 0;
// Returns the Flimflam Device client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamDeviceClient* GetFlimflamDeviceClient() = 0;
+ virtual ShillDeviceClient* GetShillDeviceClient() = 0;
- // Returns the Flimflam IPConfig client, owned by DBusThreadManager.
+ // Returns the Shill IPConfig client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamIPConfigClient* GetFlimflamIPConfigClient() = 0;
+ virtual ShillIPConfigClient* GetShillIPConfigClient() = 0;
- // Returns the Flimflam Manager client, owned by DBusThreadManager.
+ // Returns the Shill Manager client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamManagerClient* GetFlimflamManagerClient() = 0;
+ virtual ShillManagerClient* GetShillManagerClient() = 0;
- // Returns the Flimflam Network client, owned by DBusThreadManager.
+ // Returns the Shill Network client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamNetworkClient* GetFlimflamNetworkClient() = 0;
+ virtual ShillNetworkClient* GetShillNetworkClient() = 0;
- // Returns the Flimflam Profile client, owned by DBusThreadManager.
+ // Returns the Shill Profile client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamProfileClient* GetFlimflamProfileClient() = 0;
+ virtual ShillProfileClient* GetShillProfileClient() = 0;
- // Returns the Flimflam Service client, owned by DBusThreadManager.
+ // Returns the Shill Service client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.
- virtual FlimflamServiceClient* GetFlimflamServiceClient() = 0;
+ virtual ShillServiceClient* GetShillServiceClient() = 0;
// Returns the SMS client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
« no previous file with comments | « chromeos/chromeos.gyp ('k') | chromeos/dbus/dbus_thread_manager.cc » ('j') | no next file with comments »
@@ -156,35 +156,35 @@ class CHROMEOS_EXPORT DBusThreadManager {
// down.
virtual DebugDaemonClient* GetDebugDaemonClient() = 0;
- // Returns the Flimflam Device client, owned by DBusThreadManager.
+ // Returns the Shill Device client, owned by DBusThreadManager.
// Do not cache this pointer and use it after DBusThreadManager is shut
// down.

Powered by Google App Engine
This is Rietveld 408576698